@@ -17,8 +17,15 @@ def main():
 @click.argument('name')
 @click.argument('dsn')
 def inspect(name, dsn):
-    assert name == 'sql'
-    engine = sa.create_engine(dsn)
+    if name != 'sql':
+        raise click.ClickException(f"Unknown data source type {name!r}.")
+    try:
+        engine = sa.create_engine(dsn)
+    except ModuleNotFoundError as e:
+        raise click.ClickException(
+            f"Database driver not found: {e}.\n"
+            "See: https://docs.sqlalchemy.org/en/13/dialects/index.html"
+        )
     manifest = Manifest()
     dataset = Dataset('datasets/gov/data')
     resource = Resource('sqlite', dataset)
